#
# spec file for package ssh-audit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ssh-audit
Version:        2.2.0
Release:        bp153.1.14
Summary:        SSH server auditing
License:        MIT
Group:          Productivity/Security
URL:            https://github.com/jtesta/ssh-audit
Source:         https://github.com/jtesta/ssh-audit/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/jtesta/ssh-audit/releases/download/v%{version}/%{name}-%{version}.tar.gz.sig
Source2:        %{name}.keyring
BuildRequires:  python3-pytest
Requires:       python >= 3
BuildArch:      noarch

%description
ssh-audit is a tool for ssh server auditing.

Features:
 * SSH1 and SSH2 protocol server support;
 * grab banner, recognize device or software and operating system, detect compression;
 * gather key-exchange, host-key, encryption and message authentication code algorithms;
 * output algorithm information (available since, removed/disabled, unsafe/weak/legacy, etc);
 * output algorithm recommendations (append or remove based on recognized software version);
 * output security information (related issues, assigned CVE list, etc);
 * analyze SSH version compatibility based on algorithm information;
 * historical information from OpenSSH, Dropbear SSH and libssh;
 * no dependencies, compatible with Python 2.6+, Python 3.x and PyPy;

%prep
%setup -q
sed -i "s|#!/usr/bin/env python3|#!%{_bindir}/python3|g" ssh-audit.py

%build
#

%install
install -Dm0755 ssh-audit.py %{buildroot}%{_bindir}/ssh-audit

%check
# Skip tests that need a network environment
python3 -m pytest -vv -k 'not (TestResolve or test_socket or test_add_constraint_with_platform or TestSSH2)'

%files
%license LICENSE
%doc README.md
%{_bindir}/ssh-audit

%changelog
* Wed Mar 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * Marked host key type ssh-rsa as weak due to practical SHA-1
    collisions.
  * Added 10 new host key types:
    ecdsa-sha2-1.3.132.0.10, x509v3-sign-dss, x509v3-sign-rsa,
    x509v3-sign-rsa-sha256@ssh.com,
    x509v3-ssh-dss, x509v3-ssh-rsa,
    sk-ecdsa-sha2-nistp256-cert-v01@openssh.com,
    sk-ecdsa-sha2-nistp256@openssh.com,
    sk-ssh-ed25519-cert-v01@openssh.com,
    and sk-ssh-ed25519@openssh.com.
  * Added 18 new key exchanges:
    diffie-hellman-group14-sha256@ssh.com,
    diffie-hellman-group15-sha256@ssh.com,
    diffie-hellman-group15-sha384@ssh.com,
    diffie-hellman-group16-sha384@ssh.com,
    diffie-hellman-group16-sha512@ssh.com,
    diffie-hellman-group18-sha512@ssh.com,
    ecdh-sha2-curve25519, ecdh-sha2-nistb233,
    ecdh-sha2-nistb409, ecdh-sha2-nistk163,
    ecdh-sha2-nistk233, ecdh-sha2-nistk283,
    ecdh-sha2-nistk409, ecdh-sha2-nistp192,
    ecdh-sha2-nistp224, ecdh-sha2-nistt571,
    gss-gex-sha1-, and gss-group1-sha1-.
  * Added 9 new ciphers:
    camellia128-cbc, camellia128-ctr, camellia192-cbc,
    camellia192-ctr, camellia256-cbc, camellia256-ctr,
    aes128-gcm, aes256-gcm, and chacha20-poly1305.
  * Added 2 new MACs:
    aes128-gcm and aes256-gcm.
* Tue Feb  4 2020 Martin Hauke <mardnh@gmx.de>
- Rename keyring to %%name.keyring
* Mon Feb  3 2020 Martin Hauke <mardnh@gmx.de>
  * Remove _service file; use download URL for all files
  * Run spec-cleaner
  * Don't package ssh-audit with the .py extension
  * Run testsuite
* Sun Dec 29 2019 Lars Vogdt <lars@linux-schulserver.de>
- update to 2.1.1:
  This maintenance release focuses on improving support for client testing.
  The full changelog is:
  + Added 2 new host key types: rsa-sha2-256-cert-v01@openssh.com,
    rsa-sha2-512-cert-v01@openssh.com.
  + Added 2 new ciphers: des, 3des.
  + Added 3 new PuTTY vulnerabilities.
  + During client testing, client IP address is now listed in output.
- added _service file
- add signatures for source verification
* Fri Nov 15 2019 Lars Vogdt <lars@linux-schulserver.de>
- update to 2.1.0:
  The highlights of this release include client-testing functionality to audit
  the protocols accepted by client software, a JSON output format, support for
  new algorithms, and bugfixes. Below is the full changelog:
  + Added client software auditing functionality (see -c / --client-audit option).
  + Added JSON output option (see -j / --json option; credit Andreas Jaggi).
  + Fixed crash while scanning Solaris Sun_SSH.
* Wed Sep 25 2019 lars@linux-schulserver.de - 2.0.0
- initial version 2.0.0
